summaryrefslogtreecommitdiffstats
path: root/src/include/usr/hwas/common/deconfigGard.H
diff options
context:
space:
mode:
authorMatt Derksen <mderkse1@us.ibm.com>2017-07-11 15:29:50 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-09-19 12:19:56 -0400
commite561936f0efebb095b67a5acb12e5ac42cda7e59 (patch)
treeb91fa371b53c0c00d7cdc24c3325696f08c4645b /src/include/usr/hwas/common/deconfigGard.H
parent57a4232a2085a47c1025c9b4aedb2d65e625aee6 (diff)
downloadtalos-hostboot-e561936f0efebb095b67a5acb12e5ac42cda7e59.tar.gz
talos-hostboot-e561936f0efebb095b67a5acb12e5ac42cda7e59.zip
Cumulus Deconfig Updates for OBUS/ABUS/XBUS
Change-Id: Ie1badcef9185049166bc1afc5419e7d7252f2f4f RTC: 159835 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/43050 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com> Reviewed-by: Prachi Gupta <pragupta@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/include/usr/hwas/common/deconfigGard.H')
-rw-r--r--src/include/usr/hwas/common/deconfigGard.H10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/include/usr/hwas/common/deconfigGard.H b/src/include/usr/hwas/common/deconfigGard.H
index 282ffa3c3..2b6e0c779 100644
--- a/src/include/usr/hwas/common/deconfigGard.H
+++ b/src/include/usr/hwas/common/deconfigGard.H
@@ -710,13 +710,13 @@ public:
errlHndl_t deconfigureAssocProc();
/**
- * @brief Sets iv_XABusEndpointDeconfigured
+ * @brief Sets iv_XAOBusEndpointDeconfigured
*
* @param[in] deconfig Allows iv_XABusEndpointDeconfigured to be set
* to true/false
*
*/
- void setXABusEndpointDeconfigured(bool deconfig);
+ void setXAOBusEndpointDeconfigured(bool deconfig);
private:
@@ -733,14 +733,14 @@ private:
/**
* @brief Flag indicating if _deconfigureTarget has deconfigured an
- * x/a bus endpoint.
+ * x/a/o bus endpoint.
*
* Used by _invokeDeconfigureAssocProc. If true,
* _invokeDeconfigureAssocProc will execute and then call
* _deconfigureAssocProc. If false, there is no work to be done
* and _invokeDeconfigureAssocProc will break and return.
*/
- bool iv_XABusEndpointDeconfigured;
+ bool iv_XAOBusEndpointDeconfigured;
}; // DeconfigGard
OpenPOWER on IntegriCloud
@@ -710,13 +710,13 @@ public:
*
- * @param[in] deconfig Allows iv_XABusEndpointDeconfigured to be set
+ * @param[in] deconfig Allows iv_XAOBusEndpointDeconfigured to be set
* to true/false
*